﻿Imports MicroFour.StrataFrame.Application
Imports MicroFour.StrataFrame.Data

Public NotInheritable Class AppMain

  <STAThread()> _
  Public Shared Sub Main()
    '-- Enable the visual styles
    System.Windows.Forms.Application.EnableVisualStyles()

    '-- Add the handlers for the application events
    AddHandler StrataFrameApplication.ShowGateway, AddressOf ShowGateway
    AddHandler StrataFrameApplication.InitializingApplication, AddressOf InitApplication
    AddHandler StrataFrameApplication.SetDataSources, AddressOf SetDataSources
    AddHandler StrataFrameApplication.UnhandledExceptionFound, AddressOf UnhandledExceptionFound
    AddHandler StrataFrameApplication.ShowLoginAndInitializeForm, AddressOf ShowLoginAndInitMainForm

    '-- Run the application
    StrataFrameApplication.RunApplication()

    '-- Forcibly close the application to stop message pumps from looping and preventing the application 
    '   from closing
    End
  End Sub

  ''' <summary>
  ''' Gets the connection string if the application will use a custom method to aquire the connection
  ''' string rather than the StrataFrame Connection String Manager (optional)
  ''' </summary>
  ''' <remarks></remarks>
  Private Shared Sub SetDataSources()
  End Sub

  ''' <summary>
  ''' Shows the "Gateway" form (a custom form that gives the user a choice to launch different components
  ''' within the application) (optional)
  ''' </summary>
  ''' <param name="e"></param>
  ''' <remarks></remarks>
  Private Shared Sub ShowGateway(ByVal e As ShowGatewayEventArgs)
    '-- Inform the application to not show the "Gateway" form again after the main form has closed
    e.ShowGatewayAfterMainFormClose = False
  End Sub

  ''' <summary>
  ''' Shows a login form before a main form is shown and allows security to be checked before the application
  ''' launches the main form (optional)
  ''' </summary>
  ''' <param name="e"></param>
  ''' <remarks></remarks>
  Private Shared Sub ShowLoginAndInitMainForm(ByVal e As ShowLoginAndInitFormEventArgs)
    '-- ToDo: add any code to show a login form and authenticate the user
    '   e.LoginSuccessful = ?
  End Sub

  ''' <summary>
  ''' Provides a centralized location to add any initialization parameters that need to be set before
  ''' the application is loaded and defines the form types used as main forms by the application
  ''' </summary>
  ''' <param name="e"></param>
  ''' <remarks></remarks>
  Private Shared Sub InitApplication(ByVal e As InitializingApplicationEventArgs)
    '-- Add the main form type
    '-- If more than one form is added to the collection, they can be chosen by showing a "Gateway" form
    '   and supplying the index of the form to show (At least 1 form type must be added to the collection
    e.Forms.Add(GetType(MainForm))

    '-- ToDo:  Add any extra application initialization
    MicroFour.StrataFrame.UI.Localization.MessageKeyType = MicroFour.StrataFrame.Messaging.MessageKeyDataType.XML
    MicroFour.StrataFrame.UI.Localization.MessageLocaleID = MicroFour.StrataFrame.UI.Localization.GetActiveLanguage("BooleanFormatProvider")
  End Sub

  ''' <summary>
  ''' Catches any unhandled exception within the application and provides a place to log the information
  ''' </summary>
  ''' <param name="e"></param>
  ''' <remarks></remarks>
  Private Shared Sub UnhandledExceptionFound(ByVal e As UnhandledExceptionFoundEventArgs)
    '-- ToDo: add any error logging required.  To prevent the StrataFrame ApplicationErrorForm from showing,
    '   set:
    '   e.Handled = true
  End Sub

End Class